@@ -23,12 +23,11 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
 
         post_url = "https://api.askdata.com/smartnotebook/readGsheet"
         
-        #post_url = 'https://smartnotebook.askdata.com/readGsheet'
-        
         body = {
             "spreadsheetId": spreadsheetId,
             "sheet": sheet
         }
+        
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -45,12 +44,19 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
         scope = ['https://www.googleapis.com/auth/spreadsheets.readonly']
 
         cred = ServiceAccountCredentials.from_json_keyfile_dict(credentials, scope)
+        
         service = build('sheets', 'v4', credentials=cred)
     
-        sheet = service.spreadsheets()
+        sheet_service = service.spreadsheets()
         
-        result_input = sheet.values().get(spreadsheetId = spreadsheetId,
-                                          range='A1:WWW500000').execute()
+        range = 'A1:WWW500000'
+        
+        if sheet is not None:
+            
+            range = '%s!%s'%(sheet, range)
+        
+        result_input = sheet_service.values().get(spreadsheetId = spreadsheetId,
+                                          range = range).execute()
         
         values_input = result_input.get('values', [])
         
